@@ -18,8 +18,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from __future__ import absolute_import
-
 # translation
 import locale
 try:
@@ -33,7 +31,7 @@ DOMAIN = 'firewalld'
 import gettext
 gettext.install(domain=DOMAIN)
 
-from . import dbus
+from . import dbus # noqa: F401
 
 # configuration
 DAEMON_NAME = 'firewalld'
@@ -41,13 +39,14 @@ CONFIG_NAME = 'firewall-config'
 APPLET_NAME = 'firewall-applet'
 DATADIR = '/usr/share/' + DAEMON_NAME
 CONFIG_GLADE_NAME = CONFIG_NAME + '.glade'
-COPYRIGHT = '(C) 2010-2016 Red Hat, Inc.'
-VERSION = '0.4.4.3'
+COPYRIGHT = '(C) 2010-2017 Red Hat, Inc.'
+VERSION = '1.3.2'
 AUTHORS = [
     "Thomas Woerner <twoerner@redhat.com>",
     "Jiri Popelka <jpopelka@redhat.com>",
-    ]
-LICENSE = _(
+    "Eric Garver <e@erig.me>",
+]
+LICENSE = gettext.gettext(
     "This program is free software; you can redistribute it and/or modify "
     "it under the terms of the GNU General Public License as published by "
     "the Free Software Foundation; either version 2 of the License, or "
@@ -62,33 +61,46 @@ LICENSE = _(
     "along with this program.  If not, see <http://www.gnu.org/licenses/>.")
 WEBSITE = 'http://www.firewalld.org'
 
-ETC_FIREWALLD = '/etc/firewalld'
-FIREWALLD_CONF = ETC_FIREWALLD + '/firewalld.conf'
-ETC_FIREWALLD_ZONES = ETC_FIREWALLD + '/zones'
-ETC_FIREWALLD_SERVICES = ETC_FIREWALLD + '/services'
-ETC_FIREWALLD_ICMPTYPES = ETC_FIREWALLD + '/icmptypes'
-ETC_FIREWALLD_IPSETS = ETC_FIREWALLD + '/ipsets'
-ETC_FIREWALLD_HELPERS = ETC_FIREWALLD + '/helpers'
+def set_system_config_paths(path):
+    global ETC_FIREWALLD, FIREWALLD_CONF, ETC_FIREWALLD_ZONES, \
+           ETC_FIREWALLD_SERVICES, ETC_FIREWALLD_ICMPTYPES, \
+           ETC_FIREWALLD_IPSETS, ETC_FIREWALLD_HELPERS, \
+           FIREWALLD_DIRECT, LOCKDOWN_WHITELIST, ETC_FIREWALLD_POLICIES
+    ETC_FIREWALLD = path
+    FIREWALLD_CONF = path + '/firewalld.conf'
+    ETC_FIREWALLD_ZONES = path + '/zones'
+    ETC_FIREWALLD_SERVICES = path + '/services'
+    ETC_FIREWALLD_ICMPTYPES = path + '/icmptypes'
+    ETC_FIREWALLD_IPSETS = path + '/ipsets'
+    ETC_FIREWALLD_HELPERS = path + '/helpers'
+    ETC_FIREWALLD_POLICIES = path + '/policies'
+    FIREWALLD_DIRECT = path + '/direct.xml'
+    LOCKDOWN_WHITELIST = path + '/lockdown-whitelist.xml'
+set_system_config_paths('/etc/firewalld')
 
-USR_LIB_FIREWALLD = '/usr/lib/firewalld'
-FIREWALLD_ZONES = USR_LIB_FIREWALLD + '/zones'
-FIREWALLD_SERVICES = USR_LIB_FIREWALLD + '/services'
-FIREWALLD_ICMPTYPES = USR_LIB_FIREWALLD + '/icmptypes'
-FIREWALLD_IPSETS = USR_LIB_FIREWALLD + '/ipsets'
-FIREWALLD_HELPERS = USR_LIB_FIREWALLD + '/helpers'
+def set_default_config_paths(path):
+    global USR_LIB_FIREWALLD, FIREWALLD_ZONES, FIREWALLD_SERVICES, \
+           FIREWALLD_ICMPTYPES, FIREWALLD_IPSETS, FIREWALLD_HELPERS, \
+           FIREWALLD_POLICIES
+    USR_LIB_FIREWALLD = path
+    FIREWALLD_ZONES = path + '/zones'
+    FIREWALLD_SERVICES = path + '/services'
+    FIREWALLD_ICMPTYPES = path + '/icmptypes'
+    FIREWALLD_IPSETS = path + '/ipsets'
+    FIREWALLD_HELPERS = path + '/helpers'
+    FIREWALLD_POLICIES = path + '/policies'
+set_default_config_paths('/usr/lib/firewalld')
 
 FIREWALLD_LOGFILE = '/var/log/firewalld'
 
+FIREWALLD_LOGTARGET = 'mixed'
+
 FIREWALLD_PIDFILE = "/var/run/firewalld.pid"
 
 FIREWALLD_TEMPDIR = '/run/firewalld'
 
-FIREWALLD_DIRECT = ETC_FIREWALLD + '/direct.xml'
-
-LOCKDOWN_WHITELIST = ETC_FIREWALLD + '/lockdown-whitelist.xml'
-
 SYSCONFIGDIR = '/etc/sysconfig'
-IFCFGDIR = SYSCONFIGDIR + '/network-scripts'
+IFCFGDIR = "/etc/sysconfig/network-scripts"
 
 SYSCTL_CONFIG = '/etc/sysctl.conf'
 
@@ -101,20 +113,25 @@ COMMANDS = {
     "eb":           "/usr/sbin/ebtables",
     "eb-restore":   "/usr/sbin/ebtables-restore",
     "ipset":        "/usr/sbin/ipset",
-    "modinfo":      "/usr/sbin/modinfo",
     "modprobe":     "/usr/sbin/modprobe",
     "rmmod":        "/usr/sbin/rmmod",
 }
 
 LOG_DENIED_VALUES = [ "all", "unicast", "broadcast", "multicast", "off" ]
 AUTOMATIC_HELPERS_VALUES = [ "yes", "no", "system" ]
+FIREWALL_BACKEND_VALUES = [ "nftables", "iptables" ]
 
 # fallbacks: will be overloaded by firewalld.conf
 FALLBACK_ZONE = "public"
 FALLBACK_MINIMAL_MARK = 100
 FALLBACK_CLEANUP_ON_EXIT = True
+FALLBACK_CLEANUP_MODULES_ON_EXIT = False
 FALLBACK_LOCKDOWN = False
 FALLBACK_IPV6_RPFILTER = True
 FALLBACK_INDIVIDUAL_CALLS = False
 FALLBACK_LOG_DENIED = "off"
-FALLBACK_AUTOMATIC_HELPERS = "system"
+FALLBACK_AUTOMATIC_HELPERS = "no"
+FALLBACK_FIREWALL_BACKEND = "nftables"
+FALLBACK_FLUSH_ALL_ON_RELOAD = True
+FALLBACK_RFC3964_IPV4 = True
+FALLBACK_ALLOW_ZONE_DRIFTING = False
